@@ -234,7 +234,7 @@ class IntervalButtonsWidget(gtk.Table, cfg.ConfigUtils):
         self.new_int_button(_("Minor Third"),   3, 0, 1, 4, 6)
         self.new_int_button(_("Major Third"),    4, 0, 1, 6, 8)
         self.new_int_button(_("Perfect Fourth"),    5, 1, 2, 0, 2)
-        self.new_int_button(_("Diminished Fifth"),    6, 1, 2, 2, 4)
+        self.new_int_button(_("Tritone"),    6, 1, 2, 2, 4)
         self.new_int_button(_("Perfect Fifth"),    7, 1, 2, 4, 6)
         self.new_int_button(_("Minor Sixth"),  8, 1, 2, 6, 8)
         self.new_int_button(_("Major Sixth"),   9, 2, 3, 0, 2)
