@@ -96,7 +96,7 @@ if 0:
 short_name = (_i("interval|u"),
               _i("interval|m2"), _i("interval|M2"),
               _i("interval|m3"), _i("interval|M3"),
-              _i("interval|4"), _i("interval|d5"),
+              _i("interval|4"), _i("interval|tt"),
               _i("interval|5"),
               _i("interval|m6"), _i("interval|M6"),
               _i("interval|m7"), _i("interval|M7"),
